======
Errors
======

.. toctree::
   :maxdepth: 1

   100-does-not-exist
   101-permission-denied
   102-invalid-attribute
   103-not-logged-in
   104-login-failed
   105-invalid-form-data
   106-missing-attribute
   107-enable-extension-failed
   108-disable-extension-failed
   109-extension-installed
   110-install-extension-failed
   111-duplicate-item
   112-oauth-missing-scope-error
   113-oauth-access-denied-error
   114-rate-limit-exceeded
   203-invalid-change-number
   204-change-number-in-use
   205-missing-repository
   206-invalid-repository
   207-repository-file-not-found
   208-invalid-user
   209-repository-action-not-supported
   210-repository-info-error
   212-empty-changeset
   213-server-config-error
   214-bad-host-key
   215-unverified-host-key
   216-unverified-host-cert
   217-missing-user-key
   218-repo-authentication-error
   219-diff-empty
   220-diff-too-big
   221-file-retrieval-error
   222-hosting-service-auth-error
   223-group-already-exists
   224-diff-parse-error
   225-publish-error
   226-user-query-error
   227-commit-id-already-exists
   228-token-generation-failed
   230-close-error
   231-reopen-error
   232-revoke-ship-it-error
